# Morser

[![CI](https://github.com/ig0r-ferreira/morser/actions/workflows/test.yaml/badge.svg)](https://github.com/ig0r-ferreira/morser/actions/workflows/test.yaml)

Morser is a CLI for encoding and decoding morse code.

## How to install

It is recommended to use [Pipx](https://pypa.github.io/pipx/) to install the CLI:
```bash
pipx install morser
```

But you can also install with pip:
```bash
pip install morser
```

## How to use

```bash
morser --help
```

## License

This project is under license from [MIT](LICENSE).
